@@ -86,6 +86,48 @@ MODEL_CONFIGS = [
         weights_url="https://huggingface.co/stabilityai/stable-diffusion-2-depth/resolve/main/512-depth-ema.ckpt",
         default_image_size=512,
     ),
+    ModelConfig(
+        short_name="MidJourney-PaperCut",
+        config_path="configs/stable-diffusion-v1.yaml",
+        weights_url="https://huggingface.co/ShadoWxShinigamI/MidJourney-PaperCut/blob/main/Mdjrny-pprct_step_7000.ckpt",
+        default_image_size=512,
+    ),
+    ModelConfig(
+        short_name="Openjourney",
+        config_path="configs/stable-diffusion-v1.yaml",
+        weights_url="https://civitai.com/api/download/models/96",
+        default_image_size=512,
+    ),
+    ModelConfig(
+        short_name="Protogen-Anime",
+        config_path="configs/stable-diffusion-v1.yaml",
+        weights_url="https://civitai.com/api/download/models/4007",
+        default_image_size=512,
+    ),
+    ModelConfig(
+        short_name="Protogen-Photo",
+        config_path="configs/stable-diffusion-v1.yaml",
+        weights_url="https://civitai.com/api/download/models/4048",
+        default_image_size=512,
+    ),
+    ModelConfig(
+        short_name="Protogen-PhotoV2",
+        config_path="configs/stable-diffusion-v1.yaml",
+        weights_url="https://civitai.com/api/download/models/4229",
+        default_image_size=512,
+    ),
+    ModelConfig(
+        short_name="RPG",
+        config_path="configs/stable-diffusion-v1.yaml",
+        weights_url="https://huggingface.co/Anashel/rpg/blob/main/RPG-v2.ckpt",
+        default_image_size=512,
+    ),
+    ModelConfig(
+        short_name="SynthwavePunk",
+        config_path="configs/stable-diffusion-v1.yaml",
+        weights_url="https://civitai.com/api/download/models/1144",
+        default_image_size=512,
+    ),
     # ModelConfig(
     #     short_name="SD-2.0-upscale",
     #     config_path="configs/stable-diffusion-v2-upscaling.yaml",
